package com.ozs.controller.matter;


import com.alibaba.fastjson2.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.ozs.common.utils.MinioUtils;
import com.ozs.common.utils.StringUtils;
import com.ozs.service.entity.BaseMeasurePoint;
import com.ozs.service.entity.BaseRailwayManagement;
import com.ozs.service.service.BaseCameraManagementService;
import com.ozs.service.service.BaseMeasurePointService;
import com.ozs.service.service.BaseRailwayManagementService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.util.ObjectUtils;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.multipart.MultipartFile;

import javax.annotation.Resource;
import java.text.SimpleDateFormat;
import java.util.Date;

@RestController
public class MatterUploadController {

    public static final String PATTERN = "^[0-9]*$";
    @Value("${minio.bucketName}")
    private String bucketName;

    @Resource
    MinioUtils minioUtils;
    @Autowired
    BaseCameraManagementService baseCameraManagementService;
    @Autowired
    private BaseRailwayManagementService baseRailwayManagementService;
    @Autowired
    private BaseMeasurePointService baseMeasurePointService;


    @PostMapping("/api/putFile")
    public JSONObject upLoadImage(@RequestParam("stream") MultipartFile stream,
                                  @RequestParam(value = "size", required = false) Long size,
                                  @RequestParam(value = "contentType", required = false) String contentType,
                                  @RequestParam(value = "alarmMile", required = false) Integer alarmMile,
                                  @RequestParam(value = "alarmRailway", required = false) String alarmRailway,
                                  @RequestParam(value = "fileType", required = false) Integer fileType,
                                  @RequestParam(value = "fileName", required = false) String fileName,
                                  @RequestParam(value = "pointCode", required = false) String pointCode,
                                  @RequestParam(value = "lineDir", required = false) Integer lineDir) throws Exception {

        JSONObject jsonObject = new JSONObject();
        if (stream.isEmpty()) {
            jsonObject.put("resultCode", 0);
            jsonObject.put("message", "失败");
            jsonObject.put("data", "不能上传空文件哦");
            return jsonObject;
        }
        if (lineDir != 1 && lineDir != 2) {
            jsonObject.put("resultCode", 0);
            jsonObject.put("message", "失败");
            jsonObject.put("data", "行别填写错误");
            return jsonObject;
        }
        if (!alarmMile.toString().matches(PATTERN)) {
            jsonObject.put("resultCode", 0);
            jsonObject.put("message", "失败");
            jsonObject.put("data", "报警里程位置填写格式不正确");
            return jsonObject;
        }
        if (!size.toString().matches(PATTERN)) {
            jsonObject.put("resultCode", 0);
            jsonObject.put("message", "失败");
            jsonObject.put("data", "要上传的stream的填写格式不正确");
            return jsonObject;
        }
        if (ObjectUtils.isEmpty(contentType)) {
            jsonObject.put("resultCode", 0);
            jsonObject.put("message", "失败");
            jsonObject.put("data", "Content Type不能为空");
            return jsonObject;
        }
        if (ObjectUtils.isEmpty(pointCode)) {
            jsonObject.put("resultCode", 0);
            jsonObject.put("message", "失败");
            jsonObject.put("data", "测点编码不能为空");
            return jsonObject;
        }
        if (ObjectUtils.isEmpty(fileName)) {
            jsonObject.put("resultCode", 0);
            jsonObject.put("message", "失败");
            jsonObject.put("data", "文件名不能为空");
            return jsonObject;
        }
        BaseMeasurePoint one = baseMeasurePointService.getOne(new LambdaQueryWrapper<BaseMeasurePoint>()
                .eq(BaseMeasurePoint::getPointCode, pointCode));
        if (ObjectUtils.isEmpty(one)){
            jsonObject.put("resultCode", 0);
            jsonObject.put("message", "失败");
            jsonObject.put("data", "系统中不存在该测点编码");
            return jsonObject;
        }
        LambdaQueryWrapper<BaseRailwayManagement> queryWrapper = new LambdaQueryWrapper<BaseRailwayManagement>();
        if (!ObjectUtils.isEmpty(alarmRailway)) {
            queryWrapper.eq(BaseRailwayManagement::getRailwayCode, alarmRailway);
        }
        BaseRailwayManagement baseRailwayManagement = baseRailwayManagementService.getOne(queryWrapper);
        if (ObjectUtils.isEmpty(baseRailwayManagement)) {
            jsonObject.put("resultCode", 0);
            jsonObject.put("message", "失败");
            jsonObject.put("data", "填写的报警线路编码不存在");
            return jsonObject;
        }
        if (!stream.isEmpty()) {
            String imageName = stream.getOriginalFilename();
            if (StringUtils.isNotBlank(imageName)) {
                SimpleDateFormat dateFormat1 = new SimpleDateFormat("yyyyMMdd");
                String format1 = dateFormat1.format(new Date());
                String imgName = "yiwuqinxian/"+alarmRailway + "/" + pointCode + "/" + format1 + "/" + imageName;
                minioUtils.minIoClientUpload(stream.getInputStream(), imgName);
            }
        } else {
            jsonObject.put("resultCode", 0);
            jsonObject.put("message", "失败");
            jsonObject.put("data", "图片为null");
            return jsonObject;
        }
        jsonObject.put("resultCode", 1);
        jsonObject.put("message", "成功");
        jsonObject.put("data", null);
        return jsonObject;
    }
}
